..
    SPDX-License-Identifier: AGPL-3.0-or-later
    Copyright (C) 2025  Dionisis Toulatos

Device
######

.. automodule:: nirahmq.device
    :members:
    :undoc-members:
    :exclude-members: model_config
